@@ -23,12 +23,14 @@
 #include "base64.h"
 #include "crypto.h"
 #include "arcfour.h"
+#include "sockatmark.h"
+#include "oob_queue.h"
 #include "connection.h"
 #include "io.h"
 #include "error.h"
 #include "dh.h"
 
-#define VERSION			"0.1"
+#define VERSION			"0.2"
 #define LISTEN_PORT		6789	/* Default listen port	*/
 #define MAX_SIMUL_CONNECT	30	/* Default upper limit on simultaneous connections	*/
 #define TIMEOUT			10	/* 10 seconds time out for client to send conninit structure */
@@ -38,6 +40,10 @@
 #define MAX(x, y)	((x) > (y) ? (x) : (y))
 #define MIN(x, y)	((x) < (y) ? (x) : (y))
 
+#ifdef SVR4
+ typedef int socklen_t;
+#endif
+
 extern Connection *conn;
 extern int conn_size, maxfd, debug;
 extern int max_simul_con;
