@@ -3,7 +3,7 @@
 void add_proxy(char *proxy, int port, int probe) {
    struct hostent *host;
 
-   if((host = gethostbyname2(proxy, AF_INET)) == NULL) {
+   if((host = gethostbyname(proxy)) == NULL) {
       fprintf(stderr, "Add_proxy: Error resolving %s: %s\n", proxy, hstrerror(h_errno));
       exit(-1);
    }
