@@ -8,8 +8,7 @@ int probe_proxy(char *ip, int port) {
    bzero(&sin, sizeof(sin));
    sin.sin_family = AF_INET;
    sin.sin_port = htons(port);
-//   memcpy(&sin.sin_addr.s_addr, &ip, 4);
-   sin.sin_addr.s_addr = htonl(0x7f000001);
+   memcpy(&sin.sin_addr.s_addr, ip, 4);
 
    if((sd = socket(AF_INET, SOCK_DGRAM, 0)) == -1)
       err_sys("Can not create SOCK_DGRAM socket");
